"use strict";
//Compatibility https://developer.mozilla.org/en-US/docs/Web/API/Window/ongamepadconnected#Browser_compatibility
var gamePadList = [];
function isGamePadSupported() {
    return "getGamepads" in window.navigator;
}
function showGamepadNotSupported() {
    return;
}
function gamePadConnected(ee) {
    var e = ee;
    console.log('adding gamepad', e);
    var index = e.gamepad.index;
    (document.getElementById('controllerList').children[index].getElementsByClassName('controllerDescription')[0]).innerText = e.gamepad.id;
}
function gamePadDisconnected(ee) {
    var e = ee;
    console.log('removing gamepad', e);
    gamePadList = gamePadList.filter(function (x) { return x != e.gamepad; });
}
function updateController(index, g) {
    var controllerListElement = document.getElementById('controllerList');
    var gamepadElement = controllerListElement.children[index];
    updateAxes(gamepadElement, g);
    updateButtons(gamepadElement, g);
}
function updateAxes(gamepadElement, g) {
    var axesElement = gamepadElement.getElementsByClassName("axes")[0];
    if (g == null) {
        gamepadElement.style.display = 'hidden';
        return;
    }
    for (var i = 0; i < g.axes.length; ++i) {
        var axis = g.axes[i];
        if (axesElement.children.length <= i) {
            var d = document.createElement('div');
            var label;
            d.appendChild(label = document.createElement('div'));
            d.appendChild(document.createElement('div'));
            label.innerText = "Axis " + i;
            axesElement.appendChild(d);
        }
        var axisElement = axesElement.children[i];
        axisElement.children[1].innerText = axis.toFixed(3);
    }
}
function updateButtons(gamePadElement, g) {
    var buttonListElement = gamePadElement.getElementsByClassName("buttons")[0];
    if (g == null) {
        gamePadElement.style.display = 'hidden';
        return;
    }
    for (var i = 0; i < g.buttons.length; ++i) {
        var button = g.buttons[i];
        if (buttonListElement.children.length <= i) {
            var buttonElement = document.createElement('div');
            buttonListElement.appendChild(buttonElement);
            buttonElement.className = 'button';
            for (var k = 0; k < 3; ++k)
                buttonElement.appendChild(document.createElement('div'));
        }
        var targetElement = buttonListElement.children[i];
        targetElement.children[0].innerText = button.pressed ? 'pressed' : '-';
        targetElement.children[1].innerText = button.touched ? 'touched' : '-';
        targetElement.children[2].innerText = button.value.toString();
    }
}
function updateButtonList(controllerIndex, g) {
    if (g == null) {
        return;
    }
    for (var i = 0; i < g.buttons.length; ++i) {
        updateButton(i, g.buttons[i]);
    }
}
function updateButton(index, button) {
    var buttonElement = document.getElementById("button" + index);
    if (!buttonElement) {
        buttonElement = document.createElement("div");
        buttonElement.setAttribute('id', "button" + index);
        buttonElement.className = "button";
        var pressedElement = document.createElement('div');
        pressedElement.className = "pressed";
        var touchedElement = document.createElement('div');
        touchedElement.className = "touched";
        var valueElement = document.createElement('div');
        valueElement.className = "value";
        buttonElement.appendChild(pressedElement);
        buttonElement.appendChild(touchedElement);
        buttonElement.appendChild(valueElement);
        var buttonsParent = document.getElementById('buttons');
        buttonsParent.appendChild(buttonElement);
    }
    buttonElement.childNodes[0].innerText = button.pressed.toString();
    buttonElement.childNodes[1].innerText = button.touched.toString();
    buttonElement.childNodes[2].innerText = button.value.toString();
}
function start() {
    if (!isGamePadSupported()) {
        return;
    }
    window.addEventListener("gamepadconnected", gamePadConnected);
    window.addEventListener("gamepaddisconnected", gamePadDisconnected);
    setInterval(function () {
        var gpl = navigator.getGamepads();
        for (var i = 0; i < gpl.length; ++i) {
            updateController(i, gpl[i]);
        }
    }, 100);
}
window.onload = start;
