//Compatibility https://developer.mozilla.org/en-US/docs/Web/API/Window/ongamepadconnected#Browser_compatibility

declare var ongamepadconnected:any;
declare var ongamepaddisconnected:any;

var gamePadList : Array<Gamepad> = [];

function isGamePadSupported():boolean { 
    return "getGamepads" in window.navigator;
}

function showGamepadNotSupported() {
    return;
}

function gamePadConnected(ee:Event) { 
    var e:GamepadEvent = <GamepadEvent>ee;
    console.log('adding gamepad', e);
   var index = e.gamepad.index;
   (<HTMLElement>(document.getElementById('controllerList')!.children[index].getElementsByClassName('controllerDescription')[0]!)).innerText = e.gamepad.id;
}


function gamePadDisconnected(ee:Event) {
     var e:GamepadEvent = <GamepadEvent>ee;
    console.log('removing gamepad',e);
    gamePadList = gamePadList.filter((x)=>x!=e.gamepad);
}


function updateController(index:number, g:Gamepad|null):void {
    var controllerListElement:HTMLElement = document.getElementById('controllerList')!;
    var gamepadElement:HTMLElement = <HTMLElement>controllerListElement.children[index]!;
    updateAxes(gamepadElement, g);
    updateButtons(gamepadElement, g);
}


function updateAxes(gamepadElement:HTMLElement, g?:Gamepad|null):void {
    var axesElement:HTMLElement = <HTMLElement>gamepadElement.getElementsByClassName("axes")[0];
    if(g == null) {
        gamepadElement.style.display = 'hidden';
        return;
    }
    for(var i=0;i<g!.axes.length;++i) {
        var axis:Number = g!.axes[i];
        if(axesElement.children.length<=i) {
            var d = document.createElement('div');
            var label:HTMLElement;
            d.appendChild(label = document.createElement('div'));
            d.appendChild(document.createElement('div'));
            label.innerText = `Axis ${i}`
            axesElement.appendChild(d);
        }
        var axisElement = axesElement.children[i];
        (<HTMLElement>axisElement.children[1]).innerText = axis.toFixed(3); 
    }
}

function updateButtons(gamePadElement:HTMLElement, g?:Gamepad|null):void {
    var buttonListElement:HTMLElement = <HTMLElement>gamePadElement.getElementsByClassName("buttons")[0];
    if(g == null) {
        gamePadElement.style.display = 'hidden';
        return;
    }
    for(var i=0;i<g!.buttons.length;++i) {
        var button = g!.buttons[i];
        if(buttonListElement.children.length <=i) {
            var buttonElement = document.createElement('div');
            buttonListElement.appendChild(buttonElement);
            buttonElement.className = 'button';
            for(var k=0;k<3;++k)
                buttonElement.appendChild(document.createElement('div'))   
        }
        var targetElement:HTMLElement = <HTMLElement>buttonListElement.children[i];
        (<HTMLElement>targetElement.children[0]).innerText = button.pressed? 'pressed':'-';
        (<HTMLElement>targetElement.children[1]).innerText = button.touched ? 'touched':'-';
        (<HTMLElement>targetElement.children[2]).innerText = button.value.toString();
    }
}


function updateButtonList(controllerIndex:number, g:Gamepad):void {
    if(g == null) {
        return;
    }
    for(var i=0;i<g.buttons.length;++i) { 
        updateButton(i, g.buttons[i]);
    }
}

function updateButton(index:number, button:GamepadButton) {
    var buttonElement = document.getElementById(`button${index}`);
    if(!buttonElement) {
        buttonElement = document.createElement(`div`);
        buttonElement.setAttribute('id', `button${index}`);
        buttonElement.className = "button";
        var pressedElement = document.createElement('div');
        pressedElement.className = "pressed";

        var touchedElement = document.createElement('div');
        touchedElement.className = "touched";

        var valueElement = document.createElement('div');
        valueElement.className = "value";
        buttonElement.appendChild(pressedElement);
        buttonElement.appendChild(touchedElement);
        buttonElement.appendChild(valueElement);

        var buttonsParent = document.getElementById('buttons')!;
        buttonsParent.appendChild(buttonElement);
    }

    (<HTMLElement>buttonElement.childNodes[0]).innerText = button.pressed.toString();
    (<HTMLElement>buttonElement.childNodes[1]).innerText = button.touched.toString();
    (<HTMLElement>buttonElement.childNodes[2]).innerText = button.value.toString();
}

function start()  {

    if(!isGamePadSupported()) {
        return;
    }
    window.addEventListener("gamepadconnected", gamePadConnected);
    window.addEventListener("gamepaddisconnected", gamePadDisconnected);

    setInterval(function() { 
        var gpl = navigator.getGamepads()!;

       for(var i=0;i<gpl.length;++i ) {
           updateController(i, gpl[i]);
        }
    },100)
}

window.onload = start;